diff --git a/core/tests/Drupal/Tests/Core/StringTranslation/TranslationWrapperTest.php b/core/tests/Drupal/Tests/Core/StringTranslation/TranslationWrapperTest.php
index 432778a3b5664545f4a1c76138b8c4f8bdc7da60..417d771247d4ad3b15ae63550c9edc4bf7324e38 100644
--- a/core/tests/Drupal/Tests/Core/StringTranslation/TranslationWrapperTest.php
+++ b/core/tests/Drupal/Tests/Core/StringTranslation/TranslationWrapperTest.php
@@ -19,7 +19,7 @@ class TranslationWrapperTest extends UnitTestCase {
    * @group legacy
    */
   public function testTranslationWrapper() {
-    $this->expectDeprecation('Drupal\Core\StringTranslation\TranslationWrapper is deprecated in drupal:8.0.0 and is removed from drupal:10.0.0. Use the \Drupal\Core\StringTranslation\TranslatableMarkup class instead. See https://www.drupal.org/node/2571255');
+    $this->expectDeprecation('Drupal\Core\StringTranslation\TranslationWrapper is deprecated in drupal:8.0.0 and is removed from drupal:11.0.0. Use the \Drupal\Core\StringTranslation\TranslatableMarkup class instead. See https://www.drupal.org/node/2571255');
     $object = new TranslationWrapper('Deprecated');
     $this->assertInstanceOf(TranslatableMarkup::class, $object);
   }
diff --git a/core/lib/Drupal/Core/StringTranslation/TranslationWrapper.php b/core/lib/Drupal/Core/StringTranslation/TranslationWrapper.php
index 72360cedd7f53837a1785267b2f3f82bba469ea6..b68039779bcd9f8ecac6aae355cebfb2e71fddb6 100644
--- a/core/lib/Drupal/Core/StringTranslation/TranslationWrapper.php
+++ b/core/lib/Drupal/Core/StringTranslation/TranslationWrapper.php
@@ -5,7 +5,7 @@
 /**
  * Provides translatable string class.
  *
  * @deprecated in drupal:8.0.0 and is removed from drupal:10.0.0.
  *   Use the \Drupal\Core\StringTranslation\TranslatableMarkup class instead.
  *
  * @see https://www.drupal.org/node/2571255
@@ -16,7 +16,7 @@ class TranslationWrapper extends TranslatableMarkup {
    * {@inheritdoc}
    */
   public function __construct($string, array $arguments = [], array $options = [], TranslationInterface $string_translation = NULL) {
-    @trigger_error(__CLASS__ . ' is deprecated in drupal:8.0.0 and is removed from drupal:10.0.0. Use the \Drupal\Core\StringTranslation\TranslatableMarkup class instead. See https://www.drupal.org/node/2571255', E_USER_DEPRECATED);
+    @trigger_error(__CLASS__ . ' is deprecated in drupal:8.0.0 and is removed from drupal:11.0.0. Use the \Drupal\Core\StringTranslation\TranslatableMarkup class instead. See https://www.drupal.org/node/2571255', E_USER_DEPRECATED);
     parent::__construct($string, $arguments, $options, $string_translation);
   }
 
@@ -5,7 +5,7 @@
  * Provides translatable string class.
  *
- * @deprecated in drupal:8.0.0 and is removed from drupal:10.0.0.
+ * @deprecated in drupal:8.0.0 and is removed from drupal:11.0.0.
  *   Use the \Drupal\Core\StringTranslation\TranslatableMarkup class instead.
  *